@@ -1,7 +1,7 @@
 /*
     net_setup.c -- Setup.
-    Copyright (C) 1998-2004 Ivo Timmermans <ivo@tinc-vpn.org>,
-                  2000-2004 Guus Sliepen <guus@tinc-vpn.org>
+    Copyright (C) 1998-2005 Ivo Timmermans <ivo@tinc-vpn.org>,
+                  2000-2005 Guus Sliepen <guus@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: net_setup.c 1413 2004-11-10 21:56:31Z guus $
+    $Id: net_setup.c 1439 2005-05-04 18:09:30Z guus $
 */
 
 #include "system.h"
@@ -462,6 +462,10 @@ bool setup_myself(void)
 	for(i = 0; i < 5; i++)
 		free(envp[i]);
 
+	/* Run subnet-up scripts for our own subnets */
+
+	subnet_update(myself, NULL, true);
+
 	/* Open sockets */
 
 	get_config_string(lookup_config(config_tree, "BindToAddress"), &address);
@@ -568,8 +572,10 @@ void close_network_connections(void)
 		terminate_connection(c, false);
 	}
 
-	if(myself && myself->connection)
+	if(myself && myself->connection) {
+		subnet_update(myself, NULL, false);
 		terminate_connection(myself->connection, false);
+	}
 
 	for(i = 0; i < listen_sockets; i++) {
 		close(listen_socket[i].tcp);
