@@ -1,7 +1,7 @@
 /*
     net_socket.c -- Handle various kinds of sockets.
-    Copyright (C) 1998-2004 Ivo Timmermans <ivo@tinc-vpn.org>,
-                  2000-2004 Guus Sliepen <guus@tinc-vpn.org>
+    Copyright (C) 1998-2005 Ivo Timmermans <ivo@tinc-vpn.org>,
+                  2000-2005 Guus Sliepen <guus@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: net_socket.c 1413 2004-11-10 21:56:31Z guus $
+    $Id: net_socket.c 1439 2005-05-04 18:09:30Z guus $
 */
 
 #include "system.h"
@@ -424,6 +424,7 @@ bool handle_new_meta_connection(int sock)
 	sockaddrunmap(&sa);
 
 	c = new_connection();
+	c->name = NULL;
 	c->outcipher = myself->connection->outcipher;
 	c->outdigest = myself->connection->outdigest;
 	c->outmaclength = myself->connection->outmaclength;
@@ -462,8 +463,7 @@ void try_outgoing_connections(void)
 
 	cp();
 
-	for(cfg = lookup_config(config_tree, "ConnectTo"); cfg;
-		cfg = lookup_config_next(config_tree, cfg)) {
+	for(cfg = lookup_config(config_tree, "ConnectTo"); cfg; cfg = lookup_config_next(config_tree, cfg)) {
 		get_config_string(cfg, &name);
 
 		if(!check_id(name)) {
