@@ -1,7 +1,7 @@
 /*
     protocol_auth.c -- handle the meta-protocol, authentication
-    Copyright (C) 1999-2004 Ivo Timmermans <ivo@tinc-vpn.org>,
-                  2000-2004 Guus Sliepen <guus@tinc-vpn.org>
+    Copyright (C) 1999-2005 Ivo Timmermans <ivo@tinc-vpn.org>,
+                  2000-2005 Guus Sliepen <guus@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: protocol_auth.c 1374 2004-03-21 14:21:22Z guus $
+    $Id: protocol_auth.c 1439 2005-05-04 18:09:30Z guus $
 */
 
 #include "system.h"
@@ -76,8 +76,11 @@ bool id_h(connection_t *c)
 				   c->name);
 			return false;
 		}
-	} else
+	} else {
+		if(c->name)
+			free(c->name);
 		c->name = xstrdup(name);
+	}
 
 	/* Check if version matches */
 
