@@ -1,7 +1,7 @@
 /*
     protocol_subnet.c -- handle the meta-protocol, subnets
-    Copyright (C) 1999-2004 Ivo Timmermans <ivo@tinc-vpn.org>,
-                  2000-2004 Guus Sliepen <guus@tinc-vpn.org>
+    Copyright (C) 1999-2005 Ivo Timmermans <ivo@tinc-vpn.org>,
+                  2000-2005 Guus Sliepen <guus@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: protocol_subnet.c 1374 2004-03-21 14:21:22Z guus $
+    $Id: protocol_subnet.c 1439 2005-05-04 18:09:30Z guus $
 */
 
 #include "system.h"
@@ -134,6 +134,9 @@ bool add_subnet_h(connection_t *c)
 	*(new = new_subnet()) = s;
 	subnet_add(owner, new);
 
+	if(owner->status.reachable)
+		subnet_update(owner, new, true);
+
 	/* Tell the rest */
 
 	if(!tunnelserver)
@@ -229,6 +232,9 @@ bool del_subnet_h(connection_t *c)
 
 	/* Finally, delete it. */
 
+	if(owner->status.reachable)
+		subnet_update(owner, find, false);
+
 	subnet_del(owner, find);
 
 	return true;
